package com.crov.controllers;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.crov.models.Distribuidor;
import com.crov.requests.DistribuidorEditarRequest;
import com.crov.requests.DistribuidorGuadarRequest;
import com.crov.results.GenericResponse;
import com.crov.services.DistribuidorService;

@RestController
@RequestMapping("/api/distribuidores")
public class DistribuidorController {

	@Autowired
    private DistribuidorService distribuidorService;
	
	@PostMapping("/guardar")
    public ResponseEntity<GenericResponse> crearDistribuidor(@RequestBody DistribuidorGuadarRequest distribuidor) {
		
        GenericResponse response = new GenericResponse();
        if (distribuidor.getCorreo() == null || !distribuidor.getCorreo().matches("[^@]+@[^@]+")) {
        	response.setError(true);
        	response.setMessage("El correo es incorrecto");
        	response.setResult(null);
        	return ResponseEntity.badRequest().body(response);
		}
		
		// Guardar distribuidor utilizando el servicio
        Distribuidor nuevoDistribuidor = distribuidorService.guardarDistribuidor(distribuidor);
        if(nuevoDistribuidor != null) {
        	response.setError(false);
        	response.setMessage("");
        	response.getResult().add(nuevoDistribuidor);
        }
        else
        {
        	response.setError(true);
        	response.setMessage("No se guardo correctamente");
        	response.setResult(null);
        }
        return ResponseEntity.ok(response);
    }
	
	@GetMapping("/obtenerDistribuidores")
    public ResponseEntity<GenericResponse> obtenerDistribuidoresActivos() {
		GenericResponse response = new GenericResponse();
		
        List<Distribuidor> distribuidoresActivos = distribuidorService.obtenerDistribuidoresActivos();
        if(distribuidoresActivos != null) {
        	response.setError(false);
        	response.setMessage("");
        	response.getResult().addAll(distribuidoresActivos);
        }else {
        	response.setError(true);
        	response.setMessage("No pudimos obtener datos");
        	response.setResult(null);
        }
        return ResponseEntity.ok(response);
    }
	
	@GetMapping("/eliminar")
    public ResponseEntity<GenericResponse> actualizarEstadoActivo(@RequestParam Long id) {
		GenericResponse response = new GenericResponse();
		
		if(id == null || id == 0L) {
			response.setError(true);
        	response.setMessage("El id del distribuidor no debe ser 0 o nulo.");
        	response.setResult(null);
		}
		
		try{
	        Distribuidor distribuidorActualizado = distribuidorService.eliminar(id);
	        response.setError(false);
        	response.setMessage("");
        	response.getResult().add(distribuidorActualizado);
		}catch(Exception e) {
			response.setError(true);
        	response.setMessage(e.getMessage());
        	response.setResult(null);
		}
        return ResponseEntity.ok(response);
    }
	
	@GetMapping("/obtenerDistribuidor")
    public ResponseEntity<GenericResponse> obtenerDistribuidor(@RequestParam Long id) {
		GenericResponse response = new GenericResponse();
		
		if(id == null || id == 0L) {
			response.setError(true);
        	response.setMessage("El id del distribuidor no debe ser 0 o nulo.");
        	response.setResult(null);
		}
		
		try{
	        Distribuidor distribuidorActualizado = distribuidorService.obtenerDistribuidor(id);
	        response.setError(false);
        	response.setMessage("");
        	response.getResult().add(distribuidorActualizado);
		}catch(Exception e) {
			response.setError(true);
        	response.setMessage(e.getMessage());
        	response.setResult(null);
		}
        return ResponseEntity.ok(response);
    }
	
	@PostMapping("/editar")
    public ResponseEntity<GenericResponse> editarDistribuidor(@RequestBody DistribuidorEditarRequest distribuidor) {
		
        GenericResponse response = new GenericResponse();
        if (distribuidor.getCorreo() == null || !distribuidor.getCorreo().matches("[^@]+@[^@]+")) {
        	response.setError(true);
        	response.setMessage("El correo es incorrecto");
        	response.setResult(null);
        	return ResponseEntity.badRequest().body(response);
		}
		
		// Guardar distribuidor utilizando el servicio
        Distribuidor nuevoDistribuidor = distribuidorService.editarDistribuidor(distribuidor);
        if(nuevoDistribuidor != null) {
        	response.setError(false);
        	response.setMessage("");
        	response.getResult().add(nuevoDistribuidor);
        }
        else
        {
        	response.setError(true);
        	response.setMessage("No se edito correctamente");
        	response.setResult(null);
        }
        return ResponseEntity.ok(response);
    }
}
