package com.crov.controllers;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.crov.crovWSTotal.EncriptadorAES;
import com.crov.crovWSTotal.Utilerias;
import com.crov.models.ActivationKey;
import com.crov.models.ActivationKey.ActiveKey;
import com.crov.models.ActivationKey.TipoKey;
import com.crov.models.PersonSoftware;
import com.crov.models.PersonSoftware.ActivePerson;
import com.crov.models.PersonSoftware.BlackListPerson;
import com.crov.models.Software;
import com.crov.models.Software.ActiveSofware;
import com.crov.requests.PersonSoftwareRequest;
import com.crov.services.ActivationKeyService;
import com.crov.services.PersonSoftwareService;
import com.crov.services.SoftwareService;

@RestController
@CrossOrigin(origins = "http://localhost:5173")
@RequestMapping("/api/seguridadLicencias")
public class SeguridadLicenciasController {

	private static final String LICENCIA_DEMO = "0db513ee-7757-11ed-a1eb-0242ac120002";
	
	@Autowired
	ActivationKeyService actKeyServ;
	
	@Autowired
	SoftwareService softwareServ;
	
	@Autowired
	PersonSoftwareService personServ;
	
	@PostMapping("/registroLicencia")
    public ResponseEntity<Map<String, String>> registroLicencia(@RequestBody PersonSoftwareRequest licencia) throws ParseException {
	
		String token = "";

		String modulosActivos = "";
		Date fecha_expiracion;
		Integer validadorPersona = 0;
		SimpleDateFormat formato = new SimpleDateFormat("yyyy-MM-dd");
		EncriptadorAES encrip = new EncriptadorAES();
		Date today = new Date();
		
		// Observa que la llave ingresada exista y esté activa en la base de datos.
		if (actKeyServ.revisarLicenciaActivaSinUso(licencia.getActivation_key().toString()) != 1) {
			Map<String, String> map = new HashMap<>();
			map.put("Status", "Transacción fallida.");
			map.put("Token", "Llave incorrecta o utilizada.");
			return ResponseEntity.ok(map);
		}
		
		// Observa si la llave ingresada por el usuario es una de prueba.
		if (licencia.getActivation_key().toString().equals(LICENCIA_DEMO)) {
			// Se verifica que la MAc no se haya ingresado
			if (softwareServ.revisarMacExistePreviamente(licencia.getMac()) != 0) {
				Map<String, String> map = new HashMap<>();
				map.put("Status", "Transacción fallida.");
				map.put("Token", "Ya esta registrado en el sistema");
				return ResponseEntity.ok(map);
			} else {
				
				ActivationKey actKey = new ActivationKey();
				Utilerias util = new Utilerias();
				// OBtenemos la fecha actual y le sumamos 15 días (pasa los meses, años, etc)
				fecha_expiracion = (util.sumarDiasAFecha(new Date(), 30));
				String sdf = new SimpleDateFormat("yyyy-MM-dd").format(fecha_expiracion);
				// Se genera el token
				token = encrip.getAES(sdf.substring(0, 4) + licencia.getMac().substring(0, 17) + sdf.substring(5, 7)
				+ (licencia.getMac().substring(17, 45)) + sdf.substring(8, 10));
			}
		} else {
			// Verificamos que el usuario no haya sido registrado
			validadorPersona = softwareServ.revisarMacExistePreviamente(licencia.getMac().toString());
			// Significa que la llave es vitalicia o de renta
			// Generamos el modelo de ActivationKey
			ActivationKey actKey = new ActivationKey();
			// Buscamos el objeto para actualizarlo
			actKey = actKeyServ.getActivationCodePorCodigoActivacion(licencia.getActivation_key().toString());
			
			// Se actualiza
			actKeyServ.actualizarActiveKey(actKey.getId().toString());
			// Se general el token
			// Es vitalicia
			if (actKey.getActivationTime() == null) {
				token = encrip.getAES("2050" + licencia.getMac().substring(0, 17) + "01"
						+ (licencia.getMac().substring(17, 45)) + "01");
				fecha_expiracion = formato.parse("2050-01-01");
				modulosActivos = actKey.getModules();
				if (modulosActivos == null) {
					modulosActivos = "";
				} else {
					modulosActivos = encrip.getAES(modulosActivos);
				}
				// No es vitalicia
			}else {
				Utilerias util = new Utilerias();
				fecha_expiracion = (util.sumarDiasAFecha(new Date(), actKey.getActivationTime()));
				String sdf = new SimpleDateFormat("yyyy-MM-dd").format(fecha_expiracion);
				token = encrip.getAES(sdf.substring(0, 4) + licencia.getMac().substring(0, 17) + sdf.substring(5, 7)
						+ (licencia.getMac().substring(17, 45)) + sdf.substring(8, 10));
				modulosActivos = actKey.getModules();
				if (modulosActivos == null) {
					modulosActivos = "";
				} else {
					modulosActivos = encrip.getAES(modulosActivos);
				}
			}
				
		}
		
		if (validadorPersona == 0) {
			// Person vacia
			PersonSoftware person = new PersonSoftware();
			// Software vacio
			Software soft = new Software();
			
			// Se construye persona.
			token = token + "|" + modulosActivos;
			person.setFirst_name(licencia.getFirst_name());
			person.setSecond_name(licencia.getSecond_name());
			person.setLast_name(licencia.getLast_name());
			person.setMiddle_name(licencia.getMiddle_name());
			person.setMail(licencia.getMail());
			person.setBirthdate(formato.parse(licencia.getBirthdate()));
			person.setPhone(licencia.getPhone());
			person.setCreated_on(today);
			person.setActivePerson(ActivePerson.Active);
			person.setBlack_listPerson(BlackListPerson.Disabled);
			
			// Insercion de persona y se retorna el valor del ID.
			person = personServ.savePerson(person);
			
			// Se construye software
			soft.setPayment(licencia.getPayment());
			soft.setMac(licencia.getMac());
			soft.setActivation_key(licencia.getActivation_key());
			soft.setToken_product(token);
			soft.setId_software_product(licencia.getId_product());
			soft.setId_customer(person.getId());
			soft.setActiveSofware(ActiveSofware.Active);
			soft.setExpiration_date(fecha_expiracion);
			soft.setCreated_on(today);
			
			softwareServ.save(soft);
			
			Map<String, String> map = new HashMap<>();
			map.put("Token", token);
			map.put("Status", "Transacción correcta.");
			return ResponseEntity.ok(map);
		} else {
			
			// La persona ya se había registrado y es necesario actualizarla
			Software softwareModel = new Software();
			token = token + "|" + modulosActivos;
			softwareModel = softwareServ.getSofwareByMac(licencia.getMac().toString());
			softwareModel.setToken_product(token);
			softwareModel.setExpiration_date(fecha_expiracion);
			softwareModel.setPaid(1);
			softwareServ.save(softwareModel);
			Map<String, String> map = new HashMap<>();
			map.put("Token", token);
			map.put("Status", "Transacción correcta.");
			return ResponseEntity.ok(map);
		}
				
	}
	
	@PostMapping("/generarLicenciaVitalicia")
    public ResponseEntity<String> generarLicenciaVitalicia() throws ParseException {
		ActivationKey key = new ActivationKey();
		key.setActivation_code(UUID.randomUUID().toString());
		key.setActive_key(ActiveKey.Yes);
		key.setModules("2");
		key.setTipo_key(TipoKey.Lifetime);
		
		actKeyServ.generarLicenciaVitalicia(key);
		
		return ResponseEntity.ok(key.getActivation_code());
		
	}
	
}
