package com.crov.controllers;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.crov.models.Distribuidor;
import com.crov.models.Usuario;
import com.crov.requests.DistribuidorEditarRequest;
import com.crov.requests.DistribuidorGuadarRequest;
import com.crov.requests.LoginRequest;
import com.crov.requests.UsuarioEditarRequest;
import com.crov.requests.UsuarioGuardarRequest;
import com.crov.results.GenericResponse;
import com.crov.services.DistribuidorService;
import com.crov.services.UsuarioService;

@RestController
@CrossOrigin(origins = "http://localhost:5173")
@RequestMapping("/api/usuarios")
public class UsuarioController {

	@Autowired
    private UsuarioService usuarioService;
	
	@PostMapping("/guardar")
    public ResponseEntity<GenericResponse> crearUsuario(@RequestBody UsuarioGuardarRequest usuario) {
		
        GenericResponse response = new GenericResponse();
        if (usuario.getCorreo() == null || !usuario.getCorreo().matches("[^@]+@[^@]+")) {
        	response.setError(true);
        	response.setMessage("El correo es incorrecto");
        	response.setResult(null);
        	return ResponseEntity.badRequest().body(response);
		}
		
		// Guardar distribuidor utilizando el servicio
        Usuario nuevoUsuario = usuarioService.guardarUsuario(usuario);
        if(nuevoUsuario != null) {
        	response.setError(false);
        	response.setMessage("");
        	response.getResult().add(nuevoUsuario);
        }
        else
        {
        	response.setError(true);
        	response.setMessage("No se guardo correctamente");
        	response.setResult(null);
        }
        return ResponseEntity.ok(response);
    }
	
	@GetMapping("/obtenerUsuarios")
    public ResponseEntity<GenericResponse> obtenerUsuariosActivos() {
		GenericResponse response = new GenericResponse();
		
        List<Usuario> usuariosActivos = usuarioService.obtenerUsuariosActivos();
        if(usuariosActivos != null) {
        	response.setError(false);
        	response.setMessage("");
        	response.getResult().addAll(usuariosActivos);
        }else {
        	response.setError(true);
        	response.setMessage("No pudimos obtener datos");
        	response.setResult(null);
        }
        return ResponseEntity.ok(response);
    }
	
	@GetMapping("/eliminar")
    public ResponseEntity<GenericResponse> actualizarEstadoActivo(@RequestParam Long id) {
		GenericResponse response = new GenericResponse();
		
		if(id == null || id == 0L) {
			response.setError(true);
        	response.setMessage("El id del usuario no debe ser 0 o nulo.");
        	response.setResult(null);
		}
		
		try{
	        Usuario usuarioActualizado = usuarioService.eliminar(id);
	        response.setError(false);
        	response.setMessage("");
        	response.getResult().add(usuarioActualizado);
		}catch(Exception e) {
			response.setError(true);
        	response.setMessage(e.getMessage());
        	response.setResult(null);
		}
        return ResponseEntity.ok(response);
    }
	
	@GetMapping("/obtenerUsuario")
    public ResponseEntity<GenericResponse> obtenerUsuario(@RequestParam Long id) {
		GenericResponse response = new GenericResponse();
		
		if(id == null || id == 0L) {
			response.setError(true);
        	response.setMessage("El id del usuario no debe ser 0 o nulo.");
        	response.setResult(null);
		}
		
		try{
	        Usuario usuarioActualizado = usuarioService.obtenerUsuario(id);
	        response.setError(false);
        	response.setMessage("");
        	response.getResult().add(usuarioActualizado);
		}catch(Exception e) {
			response.setError(true);
        	response.setMessage(e.getMessage());
        	response.setResult(null);
		}
        return ResponseEntity.ok(response);
    }
	
	@PostMapping("/editar")
    public ResponseEntity<GenericResponse> editarUsuario(@RequestBody UsuarioEditarRequest usuario) {
		
        GenericResponse response = new GenericResponse();
        if (usuario.getCorreo() == null || !usuario.getCorreo().matches("[^@]+@[^@]+")) {
        	response.setError(true);
        	response.setMessage("El correo es incorrecto");
        	response.setResult(null);
        	return ResponseEntity.badRequest().body(response);
		}
		
		// Guardar distribuidor utilizando el servicio
        Usuario nuevoUsuario = usuarioService.editarUsuario(usuario);
        if(nuevoUsuario != null) {
        	response.setError(false);
        	response.setMessage("");
        	response.getResult().add(nuevoUsuario);
        }
        else
        {
        	response.setError(true);
        	response.setMessage("No se edito correctamente");
        	response.setResult(null);
        }
        return ResponseEntity.ok(response);
    }
	
	@PostMapping("/login")
    public ResponseEntity<?> login(@RequestBody LoginRequest loginRequest) {
        return usuarioService.login(loginRequest.getCorreo(), loginRequest.getPassword())
                .map(usuario -> ResponseEntity.ok("Login exitoso"))
                .orElse(ResponseEntity.status(401).body("Correo o contraseña incorrectos, o usuario inactivo"));
    }
}
