package com.crov.models;

import java.util.Date;

import com.crov.enums.Nivel;
import com.fasterxml.jackson.annotation.JsonFormat;

import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.EnumType;
import jakarta.persistence.Enumerated;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.GenerationType;
import jakarta.persistence.Id;
import jakarta.persistence.Table;
import jakarta.validation.constraints.Email;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Size;

@Entity
@Table(name = "distribuidor")
public class Distribuidor {

	@Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;
	
	@Column(name = "primer_nombre", nullable = false)
	@NotNull
	@Size(min = 2, message = "El nombre debe tener al menos 2 caracteres")
    private String primerNombre;
	
	@Column(name = "segundo_nombre", nullable = true)
    private String segundoNombre;
	
	@Column(name = "apellido_paterno", nullable = false)
	@NotNull
	@Size(min = 2, message = "El apellido paterno debe tener al menos 2 caracteres")
    private String apellidoPaterno;
	
	@Column(name = "apellido_materno", nullable = true)
    private String apellidoMaterno;
	
	@Column(name = "telefono", nullable = true)
    private String telefono;
	
	@Column(name = "direccion", nullable = true)
    private String direccion;
	
	@Column(name = "ciudad", nullable = true)
    private String ciudad;
	
	@Column(name = "correo", nullable = true)
	@Email(message = "Debe proporcionar un correo válido")
    private String correo;
	
	@Enumerated(EnumType.STRING)
	@Column(name = "nivel", nullable = false)
	@NotNull
    private Nivel nivel;
	
	@Column(name = "activo", nullable = false)
	@NotNull
    private boolean activo;
	
	@Column(name = "fecha_creacion", nullable = false)
	@NotNull
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    private Date fechaCreacion;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getPrimerNombre() {
		return primerNombre;
	}

	public void setPrimerNombre(String primerNombre) {
		this.primerNombre = primerNombre;
	}

	public String getSegundoNombre() {
		return segundoNombre;
	}

	public void setSegundoNombre(String segundoNombre) {
		this.segundoNombre = segundoNombre;
	}

	public String getApellidoPaterno() {
		return apellidoPaterno;
	}

	public void setApellidoPaterno(String apellidoPaterno) {
		this.apellidoPaterno = apellidoPaterno;
	}

	public String getApellidoMaterno() {
		return apellidoMaterno;
	}

	public void setApellidoMaterno(String apellidoMaterno) {
		this.apellidoMaterno = apellidoMaterno;
	}

	public String getTelefono() {
		return telefono;
	}

	public void setTelefono(String telefono) {
		this.telefono = telefono;
	}

	public String getDireccion() {
		return direccion;
	}

	public void setDireccion(String direccion) {
		this.direccion = direccion;
	}

	public String getCiudad() {
		return ciudad;
	}

	public void setCiudad(String ciudad) {
		this.ciudad = ciudad;
	}

	public String getCorreo() {
		return correo;
	}

	public void setCorreo(String correo) {
		this.correo = correo;
	}

	public Nivel getNivel() {
		return nivel;
	}

	public void setNivel(Nivel nivel) {
		this.nivel = nivel;
	}

	public boolean isActivo() {
		return activo;
	}

	public void setActivo(boolean activo) {
		this.activo = activo;
	}

	public Date getFechaCreacion() {
		return fechaCreacion;
	}

	public void setFechaCreacion(Date fechaCreacion) {
		this.fechaCreacion = fechaCreacion;
	}
	
	
}
