package com.crov.models;

import java.util.Date;
import java.util.UUID;

import com.fasterxml.jackson.annotation.JsonFormat;

import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.EnumType;
import jakarta.persistence.Enumerated;
import jakarta.persistence.Id;
import jakarta.persistence.PrePersist;
import jakarta.persistence.Table;

@Entity
@Table(name = "CUSTOMER_LICENSE_BY_PRODUCT")
public class Software {
	
	@Id
    @Column(name = "id", updatable = false, nullable = false, columnDefinition = "VARCHAR(255)")
    private String id;
	
	@PrePersist
    public void prePersist() {
        if (id == null || id.isEmpty()) {
            id = UUID.randomUUID().toString();
        }
    }
	
	private Float payment;

	@Column(unique = true, nullable = false)
	private String mac;
	
	@Column(name = "activation_key", updatable = false, nullable = false, columnDefinition = "VARCHAR(255)")
	private String activation_key;
	
	private String token_product;
	
	@Column(name ="id_software_product")
	private String id_software_product;
	
	@Column(name = "id_customer", updatable = false, nullable = false, columnDefinition = "VARCHAR(255)")
	private String id_customer;
	
	@Column(name="active", nullable = false, length = 8 )
	@Enumerated(value = EnumType.STRING)
	private ActiveSofware active;
	
	public enum ActiveSofware{
		Active,
		Inactive
	}
	
	@JsonFormat(pattern="yyyy-MM-dd")
	private Date expiration_date;
	
	@JsonFormat(pattern="yyyy-MM-dd")
	private Date created_on;
	
	private Integer paid;
	
	public Software(String id, Float payment, String mac, String activation_key, String token_product,
			String id_software_product, String id_customer, ActiveSofware active, Date expiration_date, Date created_on, Integer paid) {
		this.id = id;
		this.payment = payment;
		this.mac = mac;
		this.activation_key = activation_key;
		this.token_product = token_product;
		this.id_software_product = id_software_product;
		this.id_customer = id_customer;
		this.active = active;
		this.expiration_date = expiration_date;
		this.created_on = created_on;
		this.paid = paid;
	}
	
	public Software() {

	}

	public Software(String activation_key) {
		this.activation_key = activation_key;
	}

	public String getId() {
		return id;
	}
	public void setId(String id) {
		this.id = id;
	}
	public Float getPayment() {
		return payment;
	}
	public void setPayment(Float payment) {
		this.payment = payment;
	}
	public String getMac() {
		return mac;
	}
	public void setMac(String mac) {
		this.mac = mac;
	}
	
	public String getActivation_key() {
		return activation_key;
	}
	public void setActivation_key(String activation_key) {
		this.activation_key = activation_key;
	}
	public String getId_software_product() {
		return id_software_product;
	}
	public void setId_software_product(String id_software_product) {
		this.id_software_product = id_software_product;
	}
	public String getId_customer() {
		return id_customer;
	}
	public void setId_customer(String id_customer) {
		this.id_customer = id_customer;
	}
	public ActiveSofware getActiveSofware() {
		return active;
	}
	public void setActiveSofware(ActiveSofware active) {
		this.active = active;
	}
	public Date getExpiration_date() {
		return expiration_date;
	}
	public void setExpiration_date(Date expiration_date) {
		this.expiration_date = expiration_date;
	}
	public Date getCreated_on() {
		return created_on;
	}
	public void setCreated_on(Date created_on) {
		this.created_on = created_on;
	}
	public String getToken_product() {
		return token_product;
	}
	public void setToken_product(String token_product) {
		this.token_product = token_product;
	}
	public Integer getPaid() {
		return paid;
	}
	public void setPaid(Integer paid) {
		this.paid = paid;
	}
	
}
