package com.crov.services;

import java.security.Key;
import java.util.Date;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;
import io.jsonwebtoken.security.Keys;

@Component
public class JwtTokenUtil {

	@Value("${jwt.secret}")
    private String secret;

    @Value("${jwt.expiration}")
    private long expirationTime;
    
    // Generar el token
    public String generateToken(String username) {
    	byte[] keyBytes = secret.getBytes(); // Convierte la clave secreta en bytes
        Key signingKey = Keys.hmacShaKeyFor(keyBytes); // Crea un objeto de clave segura

        return Jwts.builder()
                .setSubject(username)
                .setIssuedAt(new Date())
                .setExpiration(new Date(System.currentTimeMillis() + expirationTime))
                .signWith(signingKey) // Firma con la clave segura
                .compact();
    }
}
