package com.crov.services;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.crov.models.Usuario;
import com.crov.repositories.UsuarioRepository;
import com.crov.requests.UsuarioEditarRequest;
import com.crov.requests.UsuarioGuardarRequest;

@Service
public class UsuarioService {

	@Autowired
    private UsuarioRepository usuarioRepository;
	
	public Usuario guardarUsuario(UsuarioGuardarRequest usuarioRequest) {
		
		Usuario usuario = new Usuario();
		
		usuario.setPrimerNombre(usuarioRequest.getPrimerNombre());
		usuario.setSegundoNombre(usuarioRequest.getSegundoNombre());
		usuario.setApellidoPaterno(usuarioRequest.getApellidoPaterno());
		usuario.setApellidoMaterno(usuarioRequest.getApellidoMaterno());
		usuario.setTelefono(usuarioRequest.getTelefono());
		usuario.setCorreo(usuarioRequest.getCorreo());
		usuario.setDireccion(usuarioRequest.getDireccion());
		usuario.setCiudad(usuarioRequest.getCiudad());
		usuario.setPerfil(usuarioRequest.getPerfil());
		
		SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
        // Convertir el String a Date
		Date dateIngreso = null;
		Date dateNacimiento = null;
		try {
			dateIngreso = formatter.parse(usuarioRequest.getFechaIngreso());
			dateNacimiento = formatter.parse(usuarioRequest.getFechaNacimiento());
		} catch (ParseException e) {
			e.printStackTrace();
		}
		usuario.setFechaIngreso(dateIngreso);
		usuario.setFechaNacimiento(dateNacimiento);
		usuario.setSueldo(usuarioRequest.getSueldo());
		usuario.setActivo(true);
		usuario.setFechaCreacion(new Date()); 
		usuario.setPassword(usuarioRequest.getPassword());
        return usuarioRepository.save(usuario);
    }
	
	public List<Usuario> obtenerUsuariosActivos() {
        return usuarioRepository.findByActivoTrue();
    }
	
	public Usuario eliminar(Long id) {
		Usuario usuario = usuarioRepository.findById(id)
                .orElseThrow(() -> new RuntimeException("Usuario no encontrado con ID: " + id));
		usuario.setActivo(false);
        return usuarioRepository.save(usuario);
    }
	
	public Usuario obtenerUsuario(Long id) {
		Usuario usuario = usuarioRepository.findById(id)
                .orElseThrow(() -> new RuntimeException("Usuario no encontrado con ID: " + id));
        return usuario;
    }
	
	public Usuario editarUsuario(UsuarioEditarRequest usuarioRequest) {
		
		Usuario usuario = usuarioRepository.findById(usuarioRequest.getId())
				.orElseThrow(() -> new RuntimeException("Usuario no encontrado con ID: " + usuarioRequest.getId()));
		
		usuario.setPrimerNombre(usuarioRequest.getPrimerNombre());
		usuario.setSegundoNombre(usuarioRequest.getSegundoNombre());
		usuario.setApellidoPaterno(usuarioRequest.getApellidoPaterno());
		usuario.setApellidoMaterno(usuarioRequest.getApellidoMaterno());
		usuario.setTelefono(usuarioRequest.getTelefono());
		usuario.setCorreo(usuarioRequest.getCorreo());
		usuario.setDireccion(usuarioRequest.getDireccion());
		usuario.setCiudad(usuarioRequest.getCiudad());
		usuario.setPerfil(usuarioRequest.getPerfil());
		usuario.setActivo(usuarioRequest.isActivo());
		SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
        // Convertir el String a Date
		Date dateIngreso = null;
		Date dateNacimiento = null;
		try {
			dateIngreso = formatter.parse(usuarioRequest.getFechaIngreso());
			dateNacimiento = formatter.parse(usuarioRequest.getFechaNacimiento());
		} catch (ParseException e) {
			e.printStackTrace();
		}
		
		usuario.setFechaIngreso(dateIngreso);
		usuario.setFechaNacimiento(dateNacimiento);
		usuario.setSueldo(usuarioRequest.getSueldo());
		
        return usuarioRepository.save(usuario);
    }
	
	public Optional<Usuario> login(String correo, String password) {
        return usuarioRepository.findByCorreoAndPasswordAndActivo(correo, password);
    }
}
